@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "numeri" "1.0.0"
+(define-package "numeri" "20250907.2357"
   "Roman Numeral Conversion Library."
   '((emacs "29.1"))
   :url "https://github.com/kickingvegas/numeri"
